# Python Bitcoin Tools Library

A Python Bitcoin Tools Library

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See deployment for notes on how to deploy the project on a live system.

### Prerequisites

What things you need to install the software and how to install them

```
Python 3 - https://www.python.org/downloads/
```

## Running the tests

```
python test.py
```

## Deployment

Add additional notes about how to deploy this on a live system

## Built With

* [Python 3](https://www.python.org)


## Authors

* **Christopher Coverdale** - *Initial work* - [ccdle12](https://github.com/ccdle12)


## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details

## Acknowledgments

* Jimmy Song
* Vitalik Buterin
* Richard Kiss

